@@ -1,4 +1,3 @@
-context("dictionary tidiers")
 
 if (requireNamespace("quanteda", quietly = TRUE)) {
   test_that("can tidy a quanteda dictionary", {
@@ -9,9 +8,9 @@ if (requireNamespace("quanteda", quietly = TRUE)) {
     d <- quanteda::dictionary(lst)
 
     td <- tidy(d)
-    expect_is(td, "tbl_df")
-    expect_is(td$category, "character")
-    expect_is(td$word, "character")
+    expect_s3_class(td, "tbl_df")
+    expect_type(td$category, "character")
+    expect_type(td$word, "character")
 
     expect_equal(nrow(td), 7)
     expect_equal(sort(unique(td$category)), c("economy", "terror"))
