@@ -1,5 +1,3 @@
-context("Stop words")
-
 suppressPackageStartupMessages(library(dplyr))
 
 test_that("get_stopwords works for multiple languages", {
@@ -7,8 +5,8 @@ test_that("get_stopwords works for multiple languages", {
   de <- get_stopwords("de")
   ru <- get_stopwords("ru")
 
-  expect_is(de, "tbl_df")
-  expect_is(ru, "tbl_df")
+  expect_s3_class(de, "tbl_df")
+  expect_s3_class(ru, "tbl_df")
   expect_gt(nrow(de), nrow(ru))
   expect_equal(unique(de$lexicon), "snowball")
 })
